@@ -155,18 +155,20 @@ fn should_add_and_take_deploys() {
         vec![],
         true,
     );
-    assert!(block.deploy_hashes().is_empty());
-    assert!(block.transfer_hashes().is_empty());
+    assert!(block.deploys().is_empty());
+    assert!(block.transfers().is_empty());
 
     // add two deploys
     proposer.add_deploy(
         block_time2,
         deploy1.deploy_or_transfer_hash(),
+        BTreeSet::new(),
         deploy1.deploy_info().unwrap(),
     );
     proposer.add_deploy(
         block_time2,
         deploy2.deploy_or_transfer_hash(),
+        BTreeSet::new(),
         deploy2.deploy_info().unwrap(),
     );
 
@@ -178,8 +180,8 @@ fn should_add_and_take_deploys() {
         vec![],
         true,
     );
-    assert!(block.deploy_hashes().is_empty());
-    assert!(block.transfer_hashes().is_empty());
+    assert!(block.deploys().is_empty());
+    assert!(block.transfers().is_empty());
 
     // if we try to create a block with a timestamp that is too late, we shouldn't get any
     // deploys, either
@@ -189,8 +191,8 @@ fn should_add_and_take_deploys() {
         vec![],
         true,
     );
-    assert!(block.deploy_hashes().is_empty());
-    assert!(block.transfer_hashes().is_empty());
+    assert!(block.deploys().is_empty());
+    assert!(block.transfers().is_empty());
 
     // take the deploys out
     let block = proposer.propose_block_payload(
@@ -199,10 +201,10 @@ fn should_add_and_take_deploys() {
         vec![],
         true,
     );
-    assert!(block.transfer_hashes().is_empty());
-    assert_eq!(block.deploy_hashes().len(), 2);
-    assert!(block.deploy_hashes().contains(deploy1.id()));
-    assert!(block.deploy_hashes().contains(deploy2.id()));
+    assert!(block.transfers().is_empty());
+    assert_eq!(block.deploys().len(), 2);
+    assert!(block.deploy_hashes().any(|hash| hash == deploy1.id()));
+    assert!(block.deploy_hashes().any(|hash| hash == deploy2.id()));
 
     // take the deploys out
     let block = proposer.propose_block_payload(
@@ -211,8 +213,8 @@ fn should_add_and_take_deploys() {
         vec![],
         true,
     );
-    assert!(block.transfer_hashes().is_empty());
-    assert_eq!(block.deploy_hashes().len(), 2);
+    assert!(block.transfers().is_empty());
+    assert_eq!(block.deploys().len(), 2);
 
     // but they shouldn't be returned if we include it in the past deploys
     let deploy_hashes = block.deploys_and_transfers_iter().collect_vec();
@@ -222,8 +224,8 @@ fn should_add_and_take_deploys() {
         vec![],
         true,
     );
-    assert!(block.deploy_hashes().is_empty());
-    assert!(block.transfer_hashes().is_empty());
+    assert!(block.deploys().is_empty());
+    assert!(block.transfers().is_empty());
 
     // finalize the block
     proposer.finalized_deploys(deploy_hashes.iter().copied());
@@ -232,11 +234,13 @@ fn should_add_and_take_deploys() {
     proposer.add_deploy(
         block_time2,
         deploy3.deploy_or_transfer_hash(),
+        BTreeSet::new(),
         deploy3.deploy_info().unwrap(),
     );
     proposer.add_deploy(
         block_time2,
         deploy4.deploy_or_transfer_hash(),
+        BTreeSet::new(),
         deploy4.deploy_info().unwrap(),
     );
 
@@ -248,10 +252,10 @@ fn should_add_and_take_deploys() {
     );
 
     // since block 1 is now finalized, neither deploy1 nor deploy2 should be among the returned
-    assert!(block.transfer_hashes().is_empty());
-    assert_eq!(block.deploy_hashes().len(), 2);
-    assert!(block.deploy_hashes().contains(deploy3.id()));
-    assert!(block.deploy_hashes().contains(deploy4.id()));
+    assert!(block.transfers().is_empty());
+    assert_eq!(block.deploys().len(), 2);
+    assert!(block.deploy_hashes().any(|hash| hash == deploy3.id()));
+    assert!(block.deploy_hashes().any(|hash| hash == deploy4.id()));
 }
 
 #[test]
@@ -300,21 +304,25 @@ fn should_successfully_prune() {
     proposer.add_deploy(
         creation_time,
         deploy1.deploy_or_transfer_hash(),
+        BTreeSet::new(),
         deploy1.deploy_info().unwrap(),
     );
     proposer.add_deploy(
         creation_time,
         deploy2.deploy_or_transfer_hash(),
+        BTreeSet::new(),
         deploy2.deploy_info().unwrap(),
     );
     proposer.add_deploy(
         creation_time,
         deploy3.deploy_or_transfer_hash(),
+        BTreeSet::new(),
         deploy3.deploy_info().unwrap(),
     );
     proposer.add_deploy(
         creation_time,
         deploy4.deploy_or_transfer_hash(),
+        BTreeSet::new(),
         deploy4.deploy_info().unwrap(),
     );
 
@@ -380,6 +388,7 @@ fn should_keep_track_of_unhandled_deploys() {
     proposer.add_deploy(
         creation_time,
         deploy1.deploy_or_transfer_hash(),
+        BTreeSet::new(),
         deploy1.deploy_info().unwrap(),
     );
     // But we DO mark it as finalized, by it's hash
@@ -416,6 +425,7 @@ fn should_keep_track_of_unhandled_deploys() {
     proposer.add_deploy(
         creation_time,
         deploy2.deploy_or_transfer_hash(),
+        BTreeSet::new(),
         deploy2.deploy_info().unwrap(),
     );
     assert!(
@@ -615,6 +625,7 @@ fn test_proposer_with(
         proposer.add_deploy(
             creation_time,
             deploy.deploy_or_transfer_hash(),
+            BTreeSet::new(),
             deploy.deploy_info().unwrap(),
         );
     }
@@ -623,6 +634,7 @@ fn test_proposer_with(
         proposer.add_deploy(
             creation_time,
             transfer.deploy_or_transfer_hash(),
+            BTreeSet::new(),
             transfer.deploy_info().unwrap(),
         );
     }
@@ -679,6 +691,7 @@ fn should_return_deploy_dependencies() {
     proposer.add_deploy(
         creation_time,
         deploy2.deploy_or_transfer_hash(),
+        BTreeSet::new(),
         deploy2.deploy_info().unwrap(),
     );
 
@@ -689,13 +702,14 @@ fn should_return_deploy_dependencies() {
         vec![],
         true,
     );
-    assert!(block.deploy_hashes().is_empty());
-    assert!(block.transfer_hashes().is_empty());
+    assert!(block.deploys().is_empty());
+    assert!(block.transfers().is_empty());
 
     // add deploy1
     proposer.add_deploy(
         creation_time,
         deploy1.deploy_or_transfer_hash(),
+        BTreeSet::new(),
         deploy1.deploy_info().unwrap(),
     );
 
@@ -720,9 +734,8 @@ fn should_return_deploy_dependencies() {
         true,
     );
     // `blocks` contains a block that contains deploy1 now, so we should get deploy2
-    let deploys2 = block.deploy_hashes();
-    assert_eq!(deploys2.len(), 1);
-    assert!(deploys2.contains(deploy2.id()));
+    assert_eq!(block.deploys().len(), 1);
+    assert!(block.deploy_hashes().any(|hash| hash == deploy2.id()));
 }
 
 #[test]
@@ -745,6 +758,7 @@ fn should_respect_deploy_delay() {
     proposer.add_deploy(
         100.into(),
         deploy.deploy_or_transfer_hash(),
+        BTreeSet::new(),
         deploy.deploy_info().unwrap(),
     );
     let block = proposer.propose_block_payload(
@@ -753,12 +767,12 @@ fn should_respect_deploy_delay() {
         vec![],
         true,
     );
-    assert!(block.deploy_hashes().is_empty());
+    assert!(block.deploys().is_empty());
     let block = proposer.propose_block_payload(
         deploy_config,
         BlockContext::new(110.into(), vec![]),
         vec![],
         true,
     );
-    assert_eq!(&vec![*deploy.id()], block.deploy_hashes());
+    assert_eq!(vec![deploy.id()], block.deploy_hashes().collect::<Vec<_>>());
 }
