@@ -3,17 +3,17 @@ use prometheus::{IntGauge, Registry};
 use crate::unregister_metric;
 
 #[derive(Debug)]
-pub(super) struct LinearChainMetrics {
+pub(super) struct Metrics {
     pub(super) block_completion_duration: IntGauge,
     /// Prometheus registry used to publish metrics.
     registry: Registry,
 }
 
-impl LinearChainMetrics {
+impl Metrics {
     pub(super) fn new(registry: &Registry) -> Result<Self, prometheus::Error> {
         let block_completion_duration = IntGauge::new(
             "block_completion_duration",
-            "duration of time from consensus through execution for a block",
+            "time in milliseconds to execute a block, from finalizing it until stored locally",
         )?;
         registry.register(Box::new(block_completion_duration.clone()))?;
         Ok(Self {
@@ -23,7 +23,7 @@ impl LinearChainMetrics {
     }
 }
 
-impl Drop for LinearChainMetrics {
+impl Drop for Metrics {
     fn drop(&mut self) {
         unregister_metric!(self.registry, self.block_completion_duration);
     }
