@@ -30,7 +30,7 @@ use crate::{
     testing::{ComponentHarness, TestRng, UnitTestEvent},
     types::{
         Block, BlockHash, BlockHeader, BlockSignatures, Deploy, DeployHash, DeployMetadata,
-        FinalitySignature, HashingAlgorithmVersion,
+        DeployWithFinalizedApprovals, FinalitySignature, HashingAlgorithmVersion,
     },
     utils::WithDir,
 };
@@ -200,7 +200,9 @@ fn get_block_signatures(
 }
 
 /// Loads a set of deploys from a storage component.
-fn get_deploys(
+///
+/// Applies `into_naive` to all loaded deploys.
+fn get_naive_deploys(
     harness: &mut ComponentHarness<UnitTestEvent>,
     storage: &mut Storage,
     deploy_hashes: Multiple<DeployHash>,
@@ -214,10 +216,15 @@ fn get_deploys(
     });
     assert!(harness.is_idle());
     response
+        .into_iter()
+        .map(|opt_dfa| opt_dfa.map(DeployWithFinalizedApprovals::into_naive))
+        .collect()
 }
 
 /// Loads a deploy with associated metadata from the storage component.
-fn get_deploy_and_metadata(
+///
+/// Any potential finalized approvals are discarded.
+fn get_naive_deploy_and_metadata(
     harness: &mut ComponentHarness<UnitTestEvent>,
     storage: &mut Storage,
     deploy_hash: DeployHash,
@@ -230,7 +237,9 @@ fn get_deploy_and_metadata(
         .into()
     });
     assert!(harness.is_idle());
-    response
+    response.map(|(deploy_with_finalized_approvals, metadata)| {
+        (deploy_with_finalized_approvals.into_naive(), metadata)
+    })
 }
 
 /// Requests the highest block from a storage component.
@@ -648,11 +657,11 @@ fn get_vec_of_non_existing_deploy_returns_nones() {
     let mut storage = storage_fixture(&harness);
 
     let deploy_id = DeployHash::random(&mut harness.rng);
-    let response = get_deploys(&mut harness, &mut storage, smallvec![deploy_id]);
+    let response = get_naive_deploys(&mut harness, &mut storage, smallvec![deploy_id]);
     assert_eq!(response, vec![None]);
 
     // Also verify that we can retrieve using an empty set of deploy hashes.
-    let response = get_deploys(&mut harness, &mut storage, smallvec![]);
+    let response = get_naive_deploys(&mut harness, &mut storage, smallvec![]);
     assert!(response.is_empty());
 }
 
@@ -675,7 +684,7 @@ fn can_retrieve_store_and_load_deploys() {
     );
 
     // Retrieve the stored deploy.
-    let response = get_deploys(&mut harness, &mut storage, smallvec![*deploy.id()]);
+    let response = get_naive_deploys(&mut harness, &mut storage, smallvec![*deploy.id()]);
     assert_eq!(response, vec![Some(deploy.as_ref().clone())]);
 
     // Finally try to get the metadata as well. Since we did not store any, we expect empty default
@@ -690,7 +699,7 @@ fn can_retrieve_store_and_load_deploys() {
         })
         .expect("no deploy with metadata returned");
 
-    assert_eq!(deploy_response, *deploy);
+    assert_eq!(deploy_response.into_naive(), *deploy);
     assert_eq!(metadata_response, DeployMetadata::default());
 }
 
@@ -715,7 +724,7 @@ fn storing_and_loading_a_lot_of_deploys_does_not_exhaust_handles() {
 
     // Retrieve all from storage, ensuring they are found.
     for chunk in deploy_hashes.chunks(batch_size) {
-        let result = get_deploys(&mut harness, &mut storage, chunk.iter().cloned().collect());
+        let result = get_naive_deploys(&mut harness, &mut storage, chunk.iter().cloned().collect());
         assert!(result.iter().all(Option::is_some));
     }
 }
@@ -735,7 +744,7 @@ fn store_execution_results_for_two_blocks() {
 
     // Ensure deploy exists.
     assert_eq!(
-        get_deploys(&mut harness, &mut storage, smallvec![*deploy.id()]),
+        get_naive_deploys(&mut harness, &mut storage, smallvec![*deploy.id()]),
         vec![Some(deploy.clone())]
     );
 
@@ -747,7 +756,7 @@ fn store_execution_results_for_two_blocks() {
 
     // Retrieve and check if correct.
     let (first_deploy, first_metadata) =
-        get_deploy_and_metadata(&mut harness, &mut storage, *deploy.id())
+        get_naive_deploy_and_metadata(&mut harness, &mut storage, *deploy.id())
             .expect("missing on first attempt");
     assert_eq!(first_deploy, deploy);
     let mut expected_per_block_results = HashMap::new();
@@ -762,7 +771,7 @@ fn store_execution_results_for_two_blocks() {
 
     // Retrieve the deploy again, should now contain both.
     let (second_deploy, second_metadata) =
-        get_deploy_and_metadata(&mut harness, &mut storage, *deploy.id())
+        get_naive_deploy_and_metadata(&mut harness, &mut storage, *deploy.id())
             .expect("missing on second attempt");
     assert_eq!(second_deploy, deploy);
     expected_per_block_results.insert(block_hash_b, second_result);
@@ -868,8 +877,9 @@ fn store_random_execution_results() {
     // At this point, we are all set up and ready to receive results. Iterate over every deploy and
     // see if its execution-data-per-block matches our expectations.
     for (deploy_hash, raw_meta) in expected_outcome.iter() {
-        let (deploy, metadata) = get_deploy_and_metadata(&mut harness, &mut storage, *deploy_hash)
-            .expect("missing deploy");
+        let (deploy, metadata) =
+            get_naive_deploy_and_metadata(&mut harness, &mut storage, *deploy_hash)
+                .expect("missing deploy");
 
         assert_eq!(deploy_hash, deploy.id());
 
@@ -1047,11 +1057,12 @@ fn persist_blocks_deploys_and_deploy_metadata_across_instantiations() {
         .expect("missing block we stored earlier");
     assert_eq!(actual_block, *block);
 
-    let actual_deploys = get_deploys(&mut harness, &mut storage, smallvec![*deploy.id()]);
+    let actual_deploys = get_naive_deploys(&mut harness, &mut storage, smallvec![*deploy.id()]);
     assert_eq!(actual_deploys, vec![Some(deploy.clone())]);
 
-    let (_, deploy_metadata) = get_deploy_and_metadata(&mut harness, &mut storage, *deploy.id())
-        .expect("missing deploy we stored earlier");
+    let (_, deploy_metadata) =
+        get_naive_deploy_and_metadata(&mut harness, &mut storage, *deploy.id())
+            .expect("missing deploy we stored earlier");
 
     let execution_results = deploy_metadata.execution_results;
     assert_eq!(execution_results.len(), 1);
@@ -1162,7 +1173,7 @@ fn should_hard_reset() {
         // Check execution results in deleted blocks have been removed.
         for (index, deploy) in deploys.iter().enumerate() {
             let (_deploy, metadata) =
-                get_deploy_and_metadata(&mut harness, &mut storage, *deploy.id()).unwrap();
+                get_naive_deploy_and_metadata(&mut harness, &mut storage, *deploy.id()).unwrap();
             let should_have_exec_results = index < blocks_per_era * reset_era;
             assert_eq!(
                 should_have_exec_results,
