@@ -5,43 +5,24 @@ use tracing::debug;
 use super::Reactor;
 use crate::unregister_metric;
 
-///Metrics for memory usage for the joiner
+/// Metrics for estimated heap memory usage for the joiner reactor.
 #[derive(Debug)]
 pub(super) struct MemoryMetrics {
-    /// Total estimated heap memory usage.
     mem_total: IntGauge,
-
-    /// Estimated heap memory usage of metrics component.
     mem_metrics: IntGauge,
-    /// Estimated heap memory usage of network component.
-    mem_network: IntGauge,
-    /// Estimated heap memory usage of small_network component.
     mem_small_network: IntGauge,
-    /// Estimated heap memory usage of address_gossiper component.
     mem_address_gossiper: IntGauge,
-    /// Estimated heap memory usage of the configuration for the validator node.
     mem_config: IntGauge,
-    /// Estimated heap memory usage for the chainspec loader component.
     mem_chainspec_loader: IntGauge,
-    /// Estimated heap memory usage of storage component.
     mem_storage: IntGauge,
-    /// Estimated heap memory usage of the contract runtime component.
     mem_contract_runtime: IntGauge,
-    /// Estimated heap memory usage of the linear chain fetcher component.
     mem_linear_chain_fetcher: IntGauge,
-    /// Estimated heap memory usage of linear chain sync.
     mem_linear_chain_sync: IntGauge,
-    /// Estimated heap memory usage of block validator component.
     mem_block_validator: IntGauge,
-    /// Estimated heap memory usage of deploy fetcher component.
     mem_deploy_fetcher: IntGauge,
-    /// Estimated heap memory usage of linear chain component.
     mem_linear_chain: IntGauge,
-
     /// Histogram detailing how long it took to estimate memory usage.
     mem_estimator_runtime_s: Histogram,
-
-    /// Instance of registry component to unregister from when being dropped.
     registry: Registry,
 }
 
@@ -50,49 +31,46 @@ impl MemoryMetrics {
     pub(super) fn new(registry: Registry) -> Result<Self, prometheus::Error> {
         let mem_total = IntGauge::new("joiner_mem_total", "total memory usage in bytes")?;
         let mem_metrics = IntGauge::new("joiner_mem_metrics", "metrics memory usage in bytes")?;
-        let mem_network = IntGauge::new("joiner_mem_network", "network memory usage in bytes")?;
-        let mem_small_network = IntGauge::new(
-            "joiner_mem_small_network",
-            "small network memory usage in bytes",
-        )?;
+        let mem_small_network =
+            IntGauge::new("joiner_mem_small_network", "network memory usage in bytes")?;
         let mem_address_gossiper = IntGauge::new(
             "joiner_mem_address_gossiper",
-            "address_gossiper memory usage in bytes",
+            "address gossiper memory usage in bytes",
         )?;
         let mem_config = IntGauge::new("joiner_mem_config", "config memory usage in bytes")?;
         let mem_chainspec_loader = IntGauge::new(
             "joiner_mem_chainspec_loader",
-            "chainspec_loader memory usage in bytes",
+            "chainspec loader memory usage in bytes",
         )?;
         let mem_storage = IntGauge::new("joiner_mem_storage", "storage memory usage in bytes")?;
         let mem_contract_runtime = IntGauge::new(
             "joiner_mem_contract_runtime",
-            "contract_runtime memory usage in bytes",
+            "contract runtime memory usage in bytes",
         )?;
         let mem_linear_chain_fetcher = IntGauge::new(
             "joiner_mem_linear_chain_fetcher",
-            "linear_chain_fetcher memory usage in bytes",
+            "linear chain fetcher memory usage in bytes",
         )?;
         let mem_linear_chain_sync = IntGauge::new(
             "joiner_mem_linear_chain_sync",
-            "linear_chain_sync memory usage in bytes",
+            "linear chain sync memory usage in bytes",
         )?;
         let mem_block_validator = IntGauge::new(
             "joiner_mem_block_validator",
-            "block_validator memory usage in bytes",
+            "block validator memory usage in bytes",
         )?;
         let mem_deploy_fetcher = IntGauge::new(
             "joiner_mem_deploy_fetcher",
-            "deploy_fetcher memory usage in bytes",
+            "deploy fetcher memory usage in bytes",
         )?;
         let mem_linear_chain = IntGauge::new(
             "joiner_mem_linear_chain",
-            "linear_chain memory usage in bytes",
+            "linear chain memory usage in bytes",
         )?;
         let mem_estimator_runtime_s = Histogram::with_opts(
             HistogramOpts::new(
                 "joiner_mem_estimator_runtime_s",
-                "time taken to estimate memory usage, in seconds",
+                "time in seconds to estimate memory usage",
             )
             // Create buckets from four nano second to eight seconds
             .buckets(prometheus::exponential_buckets(0.000_000_004, 2.0, 32)?),
@@ -100,7 +78,6 @@ impl MemoryMetrics {
 
         registry.register(Box::new(mem_total.clone()))?;
         registry.register(Box::new(mem_metrics.clone()))?;
-        registry.register(Box::new(mem_network.clone()))?;
         registry.register(Box::new(mem_small_network.clone()))?;
         registry.register(Box::new(mem_address_gossiper.clone()))?;
         registry.register(Box::new(mem_config.clone()))?;
@@ -117,7 +94,6 @@ impl MemoryMetrics {
         Ok(MemoryMetrics {
             mem_total,
             mem_metrics,
-            mem_network,
             mem_small_network,
             mem_address_gossiper,
             mem_config,
@@ -204,7 +180,6 @@ impl Drop for MemoryMetrics {
     fn drop(&mut self) {
         unregister_metric!(self.registry, self.mem_total);
         unregister_metric!(self.registry, self.mem_metrics);
-        unregister_metric!(self.registry, self.mem_network);
         unregister_metric!(self.registry, self.mem_small_network);
         unregister_metric!(self.registry, self.mem_address_gossiper);
         unregister_metric!(self.registry, self.mem_config);
