@@ -5,47 +5,27 @@ use tracing::debug;
 use super::Reactor;
 use crate::unregister_metric;
 
-/// Metrics for memory usage.
+/// Metrics for estimated heap memory usage for the participating reactor.
 #[derive(Debug)]
 pub(super) struct MemoryMetrics {
-    /// Total estimated heap memory usage.
     mem_total: IntGauge,
-
-    /// Estimated heap memory usage of metrics component.
     mem_metrics: IntGauge,
-    /// Estimated heap memory usage of network component.
     mem_net: IntGauge,
-    /// Estimated heap memory usage of address gossiper component.
     mem_address_gossiper: IntGauge,
-    /// Estimated heap memory usage of storage component.
     mem_storage: IntGauge,
-    /// Estimated heap memory usage of contract runtime component.
     mem_contract_runtime: IntGauge,
-    /// Estimated heap memory usage of rpc server component.
     mem_rpc_server: IntGauge,
-    /// Estimated heap memory usage of rest server component.
     mem_rest_server: IntGauge,
-    /// Estimated heap memory usage of event stream server component.
     mem_event_stream_server: IntGauge,
-    /// Estimated heap memory usage of chainspec loader component.
     mem_chainspec_loader: IntGauge,
-    /// Estimated heap memory usage of consensus component.
     mem_consensus: IntGauge,
-    /// Estimated heap memory usage of deploy fetcher component.
     mem_deploy_fetcher: IntGauge,
-    /// Estimated heap memory usage of deploy gossiper component.
     mem_deploy_gossiper: IntGauge,
-    /// Estimated heap memory usage of block_proposer component.
     mem_block_proposer: IntGauge,
-    /// Estimated heap memory usage of block validator component.
     mem_block_validator: IntGauge,
-    /// Estimated heap memory usage of linear chain component.
     mem_linear_chain: IntGauge,
-
     /// Histogram detailing how long it took to measure memory usage.
     mem_estimator_runtime_s: Histogram,
-
-    /// Instance of registry to unregister from when being dropped.
     registry: Registry,
 }
 
@@ -54,7 +34,7 @@ impl MemoryMetrics {
     pub(super) fn new(registry: Registry) -> Result<Self, prometheus::Error> {
         let mem_total = IntGauge::new("mem_total", "total memory usage in bytes")?;
         let mem_metrics = IntGauge::new("mem_metrics", "metrics memory usage in bytes")?;
-        let mem_net = IntGauge::new("mem_net", "net memory usage in bytes")?;
+        let mem_net = IntGauge::new("mem_net", "network memory usage in bytes")?;
         let mem_address_gossiper = IntGauge::new(
             "mem_address_gossiper",
             "address_gossiper memory usage in bytes",
@@ -62,39 +42,39 @@ impl MemoryMetrics {
         let mem_storage = IntGauge::new("mem_storage", "storage memory usage in bytes")?;
         let mem_contract_runtime = IntGauge::new(
             "mem_contract_runtime",
-            "contract_runtime memory usage in bytes",
+            "contract runtime memory usage in bytes",
         )?;
-        let mem_rpc_server = IntGauge::new("mem_rpc_server", "rpc_server memory usage in bytes")?;
+        let mem_rpc_server = IntGauge::new("mem_rpc_server", "rpc server memory usage in bytes")?;
         let mem_rest_server =
-            IntGauge::new("mem_rest_server", "mem_rest_server memory usage in bytes")?;
+            IntGauge::new("mem_rest_server", "rest server memory usage in bytes")?;
         let mem_event_stream_server = IntGauge::new(
             "mem_event_stream_server",
-            "mem_event_stream_server memory usage in bytes",
+            "event stream server memory usage in bytes",
         )?;
         let mem_chainspec_loader = IntGauge::new(
             "mem_chainspec_loader",
-            "chainspec_loader memory usage in bytes",
+            "chainspec loader memory usage in bytes",
         )?;
         let mem_consensus = IntGauge::new("mem_consensus", "consensus memory usage in bytes")?;
         let mem_deploy_fetcher =
-            IntGauge::new("mem_deploy_fetcher", "deploy_fetcher memory usage in bytes")?;
+            IntGauge::new("mem_deploy_fetcher", "deploy fetcher memory usage in bytes")?;
         let mem_deploy_gossiper = IntGauge::new(
             "mem_deploy_gossiper",
-            "deploy_gossiper memory usage in bytes",
+            "deploy gossiper memory usage in bytes",
         )?;
         let mem_block_proposer =
-            IntGauge::new("mem_block_proposer", "block_proposer memory usage in bytes")?;
+            IntGauge::new("mem_block_proposer", "block proposer memory usage in bytes")?;
         let mem_block_validator = IntGauge::new(
             "mem_block_validator",
-            "block_validator memory usage in bytes",
+            "block validator memory usage in bytes",
         )?;
         let mem_linear_chain =
-            IntGauge::new("mem_linear_chain", "linear_chain memory usage in bytes")?;
+            IntGauge::new("mem_linear_chain", "linear chain memory usage in bytes")?;
 
         let mem_estimator_runtime_s = Histogram::with_opts(
             HistogramOpts::new(
                 "mem_estimator_runtime_s",
-                "time taken to estimate memory usage, in seconds",
+                "time in seconds to estimate memory usage",
             )
             //  Create buckets from one nanosecond to eight seconds.
             .buckets(prometheus::exponential_buckets(0.000_000_004, 2.0, 32)?),
@@ -158,7 +138,6 @@ impl MemoryMetrics {
         let deploy_gossiper = reactor.deploy_gossiper.estimate_heap_size() as i64;
         let block_proposer = reactor.block_proposer.estimate_heap_size() as i64;
         let block_validator = reactor.block_validator.estimate_heap_size() as i64;
-
         let linear_chain = reactor.linear_chain.estimate_heap_size() as i64;
 
         let total = metrics
