@@ -6,7 +6,7 @@ use std::iter;
 use std::{
     array::TryFromSliceError,
     cmp::Reverse,
-    collections::BTreeMap,
+    collections::{BTreeMap, BTreeSet},
     error::Error as StdError,
     fmt::{self, Debug, Display, Formatter},
 };
@@ -37,7 +37,8 @@ use crate::{
     rpcs::docs::DocExample,
     types::{
         error::{BlockCreationError, BlockValidationError},
-        Deploy, DeployHash, DeployOrTransferHash, JsonBlock, JsonBlockHeader,
+        Approval, Deploy, DeployHash, DeployOrTransferHash, DeployWithApprovals, JsonBlock,
+        JsonBlockHeader,
     },
     utils::DisplayIter,
 };
@@ -92,12 +93,25 @@ static FINALIZED_BLOCK: Lazy<FinalizedBlock> = Lazy::new(|| {
     let transfer_hashes = vec![*Deploy::doc_example().id()];
     let random_bit = true;
     let timestamp = *Timestamp::doc_example();
-    let block_payload = BlockPayload::new(vec![], transfer_hashes, vec![], random_bit);
+    let secret_key = SecretKey::doc_example();
+    let public_key = PublicKey::from(secret_key);
+    let block_payload = BlockPayload::new(
+        vec![],
+        transfer_hashes
+            .into_iter()
+            .map(|hash| {
+                let approval = Approval::create(&hash, secret_key);
+                let mut approvals = BTreeSet::new();
+                approvals.insert(approval);
+                DeployWithApprovals::new(hash, approvals)
+            })
+            .collect(),
+        vec![],
+        random_bit,
+    );
     let era_report = Some(EraReport::doc_example().clone());
     let era_id = EraId::from(1);
     let height = 10;
-    let secret_key = SecretKey::doc_example();
-    let public_key = PublicKey::from(secret_key);
     FinalizedBlock::new(
         block_payload,
         era_report,
@@ -196,22 +210,22 @@ impl From<TryFromSliceError> for Error {
     Clone, DataSize, Debug, PartialOrd, Ord, PartialEq, Eq, Hash, Serialize, Deserialize, Default,
 )]
 pub struct BlockPayload {
-    deploy_hashes: Vec<DeployHash>,
-    transfer_hashes: Vec<DeployHash>,
+    deploys: Vec<DeployWithApprovals>,
+    transfers: Vec<DeployWithApprovals>,
     accusations: Vec<PublicKey>,
     random_bit: bool,
 }
 
 impl BlockPayload {
     pub(crate) fn new(
-        deploy_hashes: Vec<DeployHash>,
-        transfer_hashes: Vec<DeployHash>,
+        deploys: Vec<DeployWithApprovals>,
+        transfers: Vec<DeployWithApprovals>,
         accusations: Vec<PublicKey>,
         random_bit: bool,
     ) -> Self {
         BlockPayload {
-            deploy_hashes,
-            transfer_hashes,
+            deploys,
+            transfers,
             accusations,
             random_bit,
         }
@@ -222,14 +236,24 @@ impl BlockPayload {
         &self.accusations
     }
 
-    /// The list of deploy hashes included in the block, excluding transfers.
-    pub(crate) fn deploy_hashes(&self) -> &Vec<DeployHash> {
-        &self.deploy_hashes
+    /// The list of deploys included in the block, excluding transfers.
+    pub(crate) fn deploys(&self) -> &Vec<DeployWithApprovals> {
+        &self.deploys
     }
 
-    /// The list of transfer hashes included in the block.
-    pub(crate) fn transfer_hashes(&self) -> &Vec<DeployHash> {
-        &self.transfer_hashes
+    /// The list of transfers included in the block.
+    pub(crate) fn transfers(&self) -> &Vec<DeployWithApprovals> {
+        &self.transfers
+    }
+
+    /// An iterator over deploy hashes included in the block, excluding transfers.
+    pub(crate) fn deploy_hashes(&self) -> impl Iterator<Item = &DeployHash> + Clone {
+        self.deploys.iter().map(|dwa| dwa.deploy_hash())
+    }
+
+    /// An iterator over transfer hashes included in the block.
+    pub(crate) fn transfer_hashes(&self) -> impl Iterator<Item = &DeployHash> + Clone {
+        self.transfers.iter().map(|dwa| dwa.deploy_hash())
     }
 
     /// Returns an iterator over all deploys and transfers.
@@ -237,12 +261,10 @@ impl BlockPayload {
         &self,
     ) -> impl Iterator<Item = DeployOrTransferHash> + '_ {
         self.deploy_hashes()
-            .iter()
             .copied()
             .map(DeployOrTransferHash::Deploy)
             .chain(
                 self.transfer_hashes()
-                    .iter()
                     .copied()
                     .map(DeployOrTransferHash::Transfer),
             )
@@ -254,14 +276,82 @@ impl Display for BlockPayload {
         write!(
             formatter,
             "block payload: deploys {}, transfers {}, accusations {:?}, random bit {}",
-            HexList(&self.deploy_hashes),
-            HexList(&self.transfer_hashes),
+            HexList(self.deploy_hashes()),
+            HexList(self.transfer_hashes()),
             self.accusations,
             self.random_bit,
         )
     }
 }
 
+#[cfg(test)]
+impl BlockPayload {
+    #[allow(unused)] // TODO: remove when used in tests
+    pub fn random(
+        rng: &mut TestRng,
+        num_deploys: usize,
+        num_transfers: usize,
+        num_approvals: usize,
+        num_accusations: usize,
+    ) -> Self {
+        let mut total_approvals_left = num_approvals;
+        const MAX_APPROVALS_PER_DEPLOY: usize = 100;
+
+        let deploys = (0..num_deploys)
+            .map(|n| {
+                // We need at least one approval, and at least as many so that we are able to split
+                // all the remaining approvals between the remaining deploys while not exceeding
+                // the limit per deploy.
+                let min_approval_count = total_approvals_left
+                    .saturating_sub(
+                        MAX_APPROVALS_PER_DEPLOY * (num_transfers + num_deploys - n - 1),
+                    )
+                    .max(1);
+                // We have to leave at least one approval per deploy for the remaining deploys.
+                let max_approval_count = MAX_APPROVALS_PER_DEPLOY
+                    .min(total_approvals_left - (num_transfers + num_deploys - n - 1));
+                let n_approvals = rng.gen_range(min_approval_count..=max_approval_count);
+                total_approvals_left -= n_approvals;
+                DeployWithApprovals::new(
+                    DeployHash::random(rng),
+                    (0..n_approvals).map(|_| Approval::random(rng)).collect(),
+                )
+            })
+            .collect();
+
+        let transfers = (0..num_transfers)
+            .map(|n| {
+                // We need at least one approval, and at least as many so that we are able to split
+                // all the remaining approvals between the remaining transfers while not exceeding
+                // the limit per deploy.
+                let min_approval_count = total_approvals_left
+                    .saturating_sub(MAX_APPROVALS_PER_DEPLOY * (num_transfers - n - 1))
+                    .max(1);
+                // We have to leave at least one approval per transfer for the remaining transfers.
+                let max_approval_count =
+                    MAX_APPROVALS_PER_DEPLOY.min(total_approvals_left - (num_transfers - n - 1));
+                let n_approvals = rng.gen_range(min_approval_count..=max_approval_count);
+                total_approvals_left -= n_approvals;
+                DeployWithApprovals::new(
+                    DeployHash::random(rng),
+                    (0..n_approvals).map(|_| Approval::random(rng)).collect(),
+                )
+            })
+            .collect();
+
+        let accusations = (0..num_accusations)
+            .map(|_| PublicKey::random(rng))
+            .collect();
+
+        Self {
+            deploys,
+            transfers,
+            accusations,
+            random_bit: rng.gen(),
+        }
+    }
+}
+
 /// Equivocation and reward information to be included in the terminal finalized block.
 pub type EraReport = consensus::EraReport<PublicKey>;
 
@@ -338,8 +428,8 @@ impl FinalizedBlock {
         proposer: PublicKey,
     ) -> Self {
         FinalizedBlock {
-            deploy_hashes: block_payload.deploy_hashes,
-            transfer_hashes: block_payload.transfer_hashes,
+            deploy_hashes: block_payload.deploy_hashes().cloned().collect(),
+            transfer_hashes: block_payload.transfer_hashes().cloned().collect(),
             timestamp,
             random_bit: block_payload.random_bit,
             era_report,
@@ -405,14 +495,18 @@ impl FinalizedBlock {
         is_switch: bool,
     ) -> Self {
         let deploy_count = rng.gen_range(0..11);
-        let deploy_hashes =
-            iter::repeat_with(|| DeployHash::new(rng.gen::<[u8; Digest::LENGTH]>().into()))
-                .take(deploy_count)
-                .collect();
+        let deploys = iter::repeat_with(|| {
+            DeployWithApprovals::new(
+                DeployHash::new(rng.gen::<[u8; Digest::LENGTH]>().into()),
+                BTreeSet::new(),
+            )
+        })
+        .take(deploy_count)
+        .collect();
         let random_bit = rng.gen();
         // TODO - make Timestamp deterministic.
         let timestamp = Timestamp::now();
-        let block_payload = BlockPayload::new(deploy_hashes, vec![], vec![], random_bit);
+        let block_payload = BlockPayload::new(deploys, vec![], vec![], random_bit);
 
         let era_report = if is_switch {
             let equivocators_count = rng.gen_range(0..5);
